interface Foo {
    name__0: string;
}
function foo() {
    interface Foo__2 {
        name__0: string;
    }
    const foo__2 = {} as Foo__2;
}
const bar = {} as Foo;
